@@ -18,22 +18,33 @@ from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
+from .literals import MediaPipelineStatusUpdateType
 from .type_defs import (
     ChimeSdkMeetingConfigurationTypeDef,
     ConcatenationSinkTypeDef,
     ConcatenationSourceTypeDef,
     CreateMediaCapturePipelineResponseTypeDef,
     CreateMediaConcatenationPipelineResponseTypeDef,
+    CreateMediaInsightsPipelineConfigurationResponseTypeDef,
+    CreateMediaInsightsPipelineResponseTypeDef,
     CreateMediaLiveConnectorPipelineResponseTypeDef,
     EmptyResponseMetadataTypeDef,
     GetMediaCapturePipelineResponseTypeDef,
+    GetMediaInsightsPipelineConfigurationResponseTypeDef,
     GetMediaPipelineResponseTypeDef,
+    KinesisVideoStreamRecordingSourceRuntimeConfigurationTypeDef,
+    KinesisVideoStreamSourceRuntimeConfigurationTypeDef,
     ListMediaCapturePipelinesResponseTypeDef,
+    ListMediaInsightsPipelineConfigurationsResponseTypeDef,
     ListMediaPipelinesResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     LiveConnectorSinkConfigurationTypeDef,
     LiveConnectorSourceConfigurationTypeDef,
+    MediaInsightsPipelineConfigurationElementTypeDef,
+    RealTimeAlertConfigurationTypeDef,
+    S3RecordingSinkRuntimeConfigurationTypeDef,
     TagTypeDef,
+    UpdateMediaInsightsPipelineConfigurationResponseTypeDef,
 )
 
 if sys.version_info >= (3, 9):
@@ -56,6 +67,7 @@ class BotocoreClientError(BaseException):
 class Exceptions:
     BadRequestException: Type[BotocoreClientError]
     ClientError: Type[BotocoreClientError]
+    ConflictException: Type[BotocoreClientError]
     ForbiddenException: Type[BotocoreClientError]
     NotFoundException: Type[BotocoreClientError]
     ResourceLimitExceededException: Type[BotocoreClientError]
@@ -131,6 +143,42 @@ class ChimeSDKMediaPipelinesClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#create_media_concatenation_pipeline)
         """
 
+    def create_media_insights_pipeline(
+        self,
+        *,
+        MediaInsightsPipelineConfigurationArn: str,
+        KinesisVideoStreamSourceRuntimeConfiguration: KinesisVideoStreamSourceRuntimeConfigurationTypeDef = ...,
+        MediaInsightsRuntimeMetadata: Mapping[str, str] = ...,
+        KinesisVideoStreamRecordingSourceRuntimeConfiguration: KinesisVideoStreamRecordingSourceRuntimeConfigurationTypeDef = ...,
+        S3RecordingSinkRuntimeConfiguration: S3RecordingSinkRuntimeConfigurationTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...,
+        ClientRequestToken: str = ...
+    ) -> CreateMediaInsightsPipelineResponseTypeDef:
+        """
+        Creates a media insights pipeline.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.create_media_insights_pipeline)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#create_media_insights_pipeline)
+        """
+
+    def create_media_insights_pipeline_configuration(
+        self,
+        *,
+        MediaInsightsPipelineConfigurationName: str,
+        ResourceAccessRoleArn: str,
+        Elements: Sequence[MediaInsightsPipelineConfigurationElementTypeDef],
+        RealTimeAlertConfiguration: RealTimeAlertConfigurationTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...,
+        ClientRequestToken: str = ...
+    ) -> CreateMediaInsightsPipelineConfigurationResponseTypeDef:
+        """
+        A structure that contains the static configurations for a media insights
+        pipeline.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.create_media_insights_pipeline_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#create_media_insights_pipeline_configuration)
+        """
+
     def create_media_live_connector_pipeline(
         self,
         *,
@@ -140,7 +188,7 @@ class ChimeSDKMediaPipelinesClient(BaseClient):
         Tags: Sequence[TagTypeDef] = ...
     ) -> CreateMediaLiveConnectorPipelineResponseTypeDef:
         """
-        Creates a streaming media pipeline in an Amazon Chime SDK meeting.
+        Creates a media live connector pipeline in an Amazon Chime SDK meeting.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.create_media_live_connector_pipeline)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#create_media_live_connector_pipeline)
@@ -156,6 +204,16 @@ class ChimeSDKMediaPipelinesClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#delete_media_capture_pipeline)
         """
 
+    def delete_media_insights_pipeline_configuration(
+        self, *, Identifier: str
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Deletes the specified configuration settings.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.delete_media_insights_pipeline_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#delete_media_insights_pipeline_configuration)
+        """
+
     def delete_media_pipeline(self, *, MediaPipelineId: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the media pipeline.
@@ -188,6 +246,16 @@ class ChimeSDKMediaPipelinesClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#get_media_capture_pipeline)
         """
 
+    def get_media_insights_pipeline_configuration(
+        self, *, Identifier: str
+    ) -> GetMediaInsightsPipelineConfigurationResponseTypeDef:
+        """
+        Gets the configuration settings for a media insights pipeline.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.get_media_insights_pipeline_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#get_media_insights_pipeline_configuration)
+        """
+
     def get_media_pipeline(self, *, MediaPipelineId: str) -> GetMediaPipelineResponseTypeDef:
         """
         Gets an existing media pipeline.
@@ -206,6 +274,16 @@ class ChimeSDKMediaPipelinesClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#list_media_capture_pipelines)
         """
 
+    def list_media_insights_pipeline_configurations(
+        self, *, NextToken: str = ..., MaxResults: int = ...
+    ) -> ListMediaInsightsPipelineConfigurationsResponseTypeDef:
+        """
+        Lists the available media insights pipeline configurations.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.list_media_insights_pipeline_configurations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#list_media_insights_pipeline_configurations)
+        """
+
     def list_media_pipelines(
         self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListMediaPipelinesResponseTypeDef:
@@ -239,3 +317,28 @@ class ChimeSDKMediaPipelinesClient(BaseClient):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.untag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#untag_resource)
         """
+
+    def update_media_insights_pipeline_configuration(
+        self,
+        *,
+        Identifier: str,
+        ResourceAccessRoleArn: str,
+        Elements: Sequence[MediaInsightsPipelineConfigurationElementTypeDef],
+        RealTimeAlertConfiguration: RealTimeAlertConfigurationTypeDef = ...
+    ) -> UpdateMediaInsightsPipelineConfigurationResponseTypeDef:
+        """
+        Updates the media insights pipeline's configuration settings.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.update_media_insights_pipeline_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#update_media_insights_pipeline_configuration)
+        """
+
+    def update_media_insights_pipeline_status(
+        self, *, Identifier: str, UpdateStatus: MediaPipelineStatusUpdateType
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Updates the status of a media insights pipeline.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-media-pipelines.html#ChimeSDKMediaPipelines.Client.update_media_insights_pipeline_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_media_pipelines/client/#update_media_insights_pipeline_status)
+        """
