@@ -25,20 +25,34 @@ __all__ = (
     "AudioArtifactsConcatenationStateType",
     "AudioChannelsOptionType",
     "AudioMuxTypeType",
+    "CallAnalyticsLanguageCodeType",
     "ConcatenationSinkTypeType",
     "ConcatenationSourceTypeType",
     "ContentMuxTypeType",
+    "ContentRedactionOutputType",
     "ContentShareLayoutOptionType",
+    "ContentTypeType",
+    "FragmentSelectorTypeType",
     "LayoutOptionType",
     "LiveConnectorMuxTypeType",
     "LiveConnectorSinkTypeType",
     "LiveConnectorSourceTypeType",
+    "MediaEncodingType",
+    "MediaInsightsPipelineConfigurationElementTypeType",
     "MediaPipelineSinkTypeType",
     "MediaPipelineSourceTypeType",
     "MediaPipelineStatusType",
+    "MediaPipelineStatusUpdateType",
+    "PartialResultsStabilityType",
+    "ParticipantRoleType",
     "PresenterPositionType",
+    "RealTimeAlertRuleTypeType",
+    "RecordingFileFormatType",
     "ResolutionOptionType",
+    "SentimentTypeType",
     "VideoMuxTypeType",
+    "VocabularyFilterMethodType",
+    "VoiceAnalyticsConfigurationStatusType",
     "ChimeSDKMediaPipelinesServiceName",
     "ServiceName",
     "ResourceServiceName",
@@ -51,20 +65,47 @@ ArtifactsStateType = Literal["Disabled", "Enabled"]
 AudioArtifactsConcatenationStateType = Literal["Enabled"]
 AudioChannelsOptionType = Literal["Mono", "Stereo"]
 AudioMuxTypeType = Literal["AudioOnly", "AudioWithActiveSpeakerVideo", "AudioWithCompositedVideo"]
+CallAnalyticsLanguageCodeType = Literal[
+    "de-DE", "en-AU", "en-GB", "en-US", "es-US", "fr-CA", "fr-FR", "it-IT", "pt-BR"
+]
 ConcatenationSinkTypeType = Literal["S3Bucket"]
 ConcatenationSourceTypeType = Literal["MediaCapturePipeline"]
 ContentMuxTypeType = Literal["ContentOnly"]
+ContentRedactionOutputType = Literal["redacted", "redacted_and_unredacted"]
 ContentShareLayoutOptionType = Literal["Horizontal", "PresenterOnly", "Vertical"]
+ContentTypeType = Literal["PII"]
+FragmentSelectorTypeType = Literal["ProducerTimestamp", "ServerTimestamp"]
 LayoutOptionType = Literal["GridView"]
 LiveConnectorMuxTypeType = Literal["AudioWithActiveSpeakerVideo", "AudioWithCompositedVideo"]
 LiveConnectorSinkTypeType = Literal["RTMP"]
 LiveConnectorSourceTypeType = Literal["ChimeSdkMeeting"]
+MediaEncodingType = Literal["pcm"]
+MediaInsightsPipelineConfigurationElementTypeType = Literal[
+    "AmazonTranscribeCallAnalyticsProcessor",
+    "AmazonTranscribeProcessor",
+    "KinesisDataStreamSink",
+    "LambdaFunctionSink",
+    "S3RecordingSink",
+    "SnsTopicSink",
+    "SqsQueueSink",
+    "VoiceAnalyticsProcessor",
+]
 MediaPipelineSinkTypeType = Literal["S3Bucket"]
 MediaPipelineSourceTypeType = Literal["ChimeSdkMeeting"]
-MediaPipelineStatusType = Literal["Failed", "InProgress", "Initializing", "Stopped", "Stopping"]
+MediaPipelineStatusType = Literal[
+    "Failed", "InProgress", "Initializing", "Paused", "Stopped", "Stopping"
+]
+MediaPipelineStatusUpdateType = Literal["Pause", "Resume"]
+PartialResultsStabilityType = Literal["high", "low", "medium"]
+ParticipantRoleType = Literal["AGENT", "CUSTOMER"]
 PresenterPositionType = Literal["BottomLeft", "BottomRight", "TopLeft", "TopRight"]
+RealTimeAlertRuleTypeType = Literal["IssueDetection", "KeywordMatch", "Sentiment"]
+RecordingFileFormatType = Literal["Opus", "Wav"]
 ResolutionOptionType = Literal["FHD", "HD"]
+SentimentTypeType = Literal["NEGATIVE"]
 VideoMuxTypeType = Literal["VideoOnly"]
+VocabularyFilterMethodType = Literal["mask", "remove", "tag"]
+VoiceAnalyticsConfigurationStatusType = Literal["Disabled", "Enabled"]
 ChimeSDKMediaPipelinesServiceName = Literal["chime-sdk-media-pipelines"]
 ServiceName = Literal[
     "accessanalyzer",
@@ -90,6 +131,7 @@ ServiceName = Literal[
     "apprunner",
     "appstream",
     "appsync",
+    "arc-zonal-shift",
     "athena",
     "auditmanager",
     "autoscaling",
@@ -107,6 +149,8 @@ ServiceName = Literal[
     "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
+    "chime-sdk-voice",
+    "cleanrooms",
     "cloud9",
     "cloudcontrol",
     "clouddirectory",
@@ -117,9 +161,11 @@ ServiceName = Literal[
     "cloudsearch",
     "cloudsearchdomain",
     "cloudtrail",
+    "cloudtrail-data",
     "cloudwatch",
     "codeartifact",
     "codebuild",
+    "codecatalyst",
     "codecommit",
     "codedeploy",
     "codeguru-reviewer",
@@ -156,6 +202,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "docdb-elastic",
     "drs",
     "ds",
     "dynamodb",
@@ -208,9 +255,11 @@ ServiceName = Literal[
     "importexport",
     "inspector",
     "inspector2",
+    "internetmonitor",
     "iot",
     "iot-data",
     "iot-jobs-data",
+    "iot-roborunner",
     "iot1click-devices",
     "iot1click-projects",
     "iotanalytics",
@@ -225,15 +274,18 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivs-realtime",
     "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
+    "kendra-ranking",
     "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
     "kinesis-video-signaling",
+    "kinesis-video-webrtc-storage",
     "kinesisanalytics",
     "kinesisanalyticsv2",
     "kinesisvideo",
@@ -245,6 +297,7 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-linux-subscriptions",
     "license-manager-user-subscriptions",
     "lightsail",
     "location",
@@ -284,7 +337,10 @@ ServiceName = Literal[
     "network-firewall",
     "networkmanager",
     "nimble",
+    "oam",
+    "omics",
     "opensearch",
+    "opensearchserverless",
     "opsworks",
     "opsworkscm",
     "organizations",
@@ -298,6 +354,7 @@ ServiceName = Literal[
     "pinpoint-email",
     "pinpoint-sms-voice",
     "pinpoint-sms-voice-v2",
+    "pipes",
     "polly",
     "pricing",
     "privatenetworks",
@@ -314,6 +371,7 @@ ServiceName = Literal[
     "redshift-serverless",
     "rekognition",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -332,12 +390,16 @@ ServiceName = Literal[
     "sagemaker-a2i-runtime",
     "sagemaker-edge",
     "sagemaker-featurestore-runtime",
+    "sagemaker-geospatial",
+    "sagemaker-metrics",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
     "securityhub",
+    "securitylake",
     "serverlessrepo",
     "service-quotas",
     "servicecatalog",
@@ -347,6 +409,7 @@ ServiceName = Literal[
     "sesv2",
     "shield",
     "signer",
+    "simspaceweaver",
     "sms",
     "sms-voice",
     "snow-device-management",
@@ -356,6 +419,7 @@ ServiceName = Literal[
     "ssm",
     "ssm-contacts",
     "ssm-incidents",
+    "ssm-sap",
     "sso",
     "sso-admin",
     "sso-oidc",
@@ -369,6 +433,7 @@ ServiceName = Literal[
     "textract",
     "timestream-query",
     "timestream-write",
+    "tnb",
     "transcribe",
     "transfer",
     "translate",
